package gwtop.exemple.client.base;

import gwtop.exemple.client.base.manager.IMyScreens;
import gwtop.exemple.client.base.provider.IScreenProvider;
import gwtop.exemple.client.base.provider.person.PersonCreateProvider;
import gwtop.exemple.client.base.provider.person.PersonFindProvider;
import gwtop.exemple.client.base.provider.person.PersonReadProvider;
import gwtop.exemple.client.base.provider.person.PersonUpdateProvider;
import gwtop.fwk.manager.IPanelsBuilder;
import gwtop.fwk.mvpe.screen.IScreen;

import java.util.HashMap;
import java.util.Map;

/**
 * The Class MyPanelBuilder.
 */
public class MyPanelBuilder implements IPanelsBuilder {

    /** The providers. */
    private final Map<String, IScreenProvider> providers;

    /**
     * Instantiates a new my panel builder.
     */
    public MyPanelBuilder() {
        super();
        this.providers = new HashMap<String, IScreenProvider>();
        // We put screens providers in memory
        this.providers.put(IMyScreens.personRead, new PersonReadProvider());
        this.providers.put(IMyScreens.personCreate, new PersonCreateProvider());
        this.providers.put(IMyScreens.personFind, new PersonFindProvider());
        this.providers.put(IMyScreens.personUpdate, new PersonUpdateProvider());
    }

    /**
     * {@inheritDoc}
     */
    public IScreen buildPanel(final String panelId, final String beanId, final String tabId,
            final boolean isHistorise) {
        IScreen panel = null;
        if (null == panelId) {
            return null;
        }
        final IScreenProvider provider = this.providers.get(panelId);
        if (provider != null) {
            // With this 2 args we can open all type of screens
            panel = provider.run(beanId, tabId);
        }
        return panel;
    }
}
