package gwtop.exemple.client.base.menu;

import gwtop.exemple.client.base.manager.IMyScreens;

import com.google.gwt.user.client.Command;
import com.google.gwt.user.client.ui.MenuBar;
import com.google.gwt.user.client.ui.MenuItem;

/**
 * The Class MenuBuilder.
 */
public final class MenuBuilder {

    /**
     * Builds the item person.
     * @param text
     *            the text
     * @param panelId
     *            the panel id
     * @param beanId
     *            the bean id
     * @return the menu item
     */
    private static MenuItem buildItemPerson(final String text, final String panelId,
            final String beanId) {
        final Command cmdRead = new MenuCommand(panelId, beanId);
        return new MenuItem(text, cmdRead);
    }

    /**
     * Builds the menu.
     * @return the menu bar
     */
    public static MenuBar buildMenu() {
        final MenuBar menu = new MenuBar();
        menu.setAnimationEnabled(true);
        menu.setAutoOpen(true);

        final MenuBar menuPerson = buildMenuPerson();

        final MenuItem itemCat1 = new MenuItem("Person", menuPerson);
        menu.addItem(itemCat1);

        return menu;
    }

    /**
     * Builds the menu person.
     * @return the menu bar
     */
    private static MenuBar buildMenuPerson() {
        final MenuBar menuPerson = new MenuBar(true);

        final MenuItem itemRead1 = buildItemPerson("Read 1", IMyScreens.personRead, "1");
        final MenuItem itemRead2 = buildItemPerson("Read 2", IMyScreens.personRead, "2");
        final MenuItem itemRead3 = buildItemPerson("Create Person", IMyScreens.personCreate, "3");
        final MenuItem itemRead4 = buildItemPerson("Find Person", IMyScreens.personFind, "4");

        menuPerson.addItem(itemRead1);
        menuPerson.addItem(itemRead2);
        menuPerson.addItem(itemRead3);
        menuPerson.addItem(itemRead4);
        return menuPerson;
    }

    /**
     * Instantiates a new menu builder.
     */
    private MenuBuilder() {
        super();
    }
}
