package gwtop.exemple.client.person.commons.screen;

import gwtop.exemple.client.base.ui.panel.H2Panel;
import gwtop.exemple.client.base.ui.panel.ScreenPanel;
import gwtop.exemple.client.person.commons.command.PersonReadCommand;
import gwtop.exemple.client.person.commons.presenter.IPersonPresenter;
import gwtop.exemple.client.person.commons.view.PersonView;
import gwtop.exemple.shared.bo.person.Person;
import gwtop.fwk.mvpe.screen.AScreen;

import com.google.gwt.user.client.ui.Panel;

/**
 * The Class APersonScreen.
 */
public class APersonScreen extends AScreen implements IPersonScreen {

    /** The bean. */
    private Person bean;

    /** The cmd. */
    private final PersonReadCommand cmd = new PersonReadCommand(this);

    /** The h2 panel. */
    private final H2Panel h2Panel;

    /** The presenter. */
    private final IPersonPresenter presenter;

    /** The view. */
    private final PersonView view;

    /**
     * Instantiates a new a person screen.
     * @param pPresenter
     *            the presenter
     * @param title
     *            the title
     */
    public APersonScreen(final IPersonPresenter pPresenter, final String title) {
        super();
        this.h2Panel = new H2Panel(title);
        this.presenter = pPresenter;
        this.view = new PersonView(pPresenter);
    }

    /**
     * {@inheritDoc}
     */
    public Panel createPanel() {
        final Panel screenPanel = new ScreenPanel(this.h2Panel);
        final Panel contentPanel = this.view.createPanel();
        screenPanel.add(contentPanel);
        return screenPanel;
    }

    /**
     * {@inheritDoc}
     */
    public Person getBean() {
        return this.bean;
    }

    /**
     * Gets the command.
     * @return the command
     */
    public PersonReadCommand getCommand() {
        return this.cmd;
    }

    /**
     * Gets the h2.
     * @return the h2
     */
    public H2Panel getH2() {
        return this.h2Panel;
    }

    /**
     * {@inheritDoc}
     */
    public IPersonPresenter getPresenter() {
        return this.presenter;
    }

    /**
     * {@inheritDoc}
     */
    public void setBean(final Person pBean) {
        this.bean = pBean;
    }

}
