package gwtop.exemple.client.person.find;

import gwtop.exemple.client.base.manager.IMsgs;
import gwtop.exemple.client.person.find.sorted.PersonFindHandler;
import gwtop.exemple.shared.bo.person.Person;
import gwtop.exemple.shared.dto.person.PersonCriteria;
import gwtop.exemple.shared.id.person.PersonId;
import gwtop.fwk.common.SortedHeader;
import gwtop.fwk.common.SortedSelection;
import gwtop.fwk.mvpe.event.handler.BasicClickHandler;
import gwtop.fwk.mvpe.presenter.APresenterFind;
import gwtop.fwk.ui.input.InputTextBox;
import gwtop.fwk.ui.output.TableGTP;
import gwtop.fwk.ui.td.CurrencyTd;
import gwtop.fwk.ui.td.LongTd;
import gwtop.fwk.ui.value.BooleanValue;
import gwtop.fwk.ui.value.DateValue;
import gwtop.fwk.ui.value.HeaderSortedValue;
import gwtop.fwk.ui.value.TextValue;

import java.util.List;

import com.google.gwt.event.dom.client.ClickHandler;
import com.google.gwt.user.client.Command;
import com.google.gwt.user.client.ui.Button;
import com.google.gwt.user.client.ui.Widget;

/**
 * The Class PersonFindPresenter.
 */
public class PersonFindPresenter extends APresenterFind<List<Person>, PersonCriteria> implements
        IPersonFindPresenter {

    /** The name. */
    private final InputTextBox name;

    /** The result. */
    private final TableGTP result;

    /** The search. */
    private final Button search;

    /** The sorted. */
    private final SortedSelection sorted;

    /** The sorted handler. */
    private final ClickHandler sortedHandler;

    /**
     * Instantiates a new person find presenter.
     * @param pCmd
     *            the cmd
     */
    public PersonFindPresenter(final Command pCmd) {
        super();
        this.result = new TableGTP(IMsgs.global.results());
        this.name = new InputTextBox(PersonId.name, IMsgs.person.name(), false);
        this.search = new Button(IMsgs.global.search());

        this.search.addClickHandler(new BasicClickHandler(pCmd));

        this.sorted = new SortedSelection();
        this.sortedHandler = new PersonFindHandler(pCmd, this.sorted);

        this.attachElements();
    }

    /**
     * Attach elements.
     */
    private void attachElements() {
        this.attachInput(this.name);
        this.attachMainButton(this.search);

    }

    /**
     * Builds the header.
     * @param h
     *            the h
     * @return the widget
     */
    private Widget buildHeader(final SortedHeader h) {
        return new HeaderSortedValue(h, this.sortedHandler);
    }

    /**
     * Gets the name.
     * @return the name
     */
    public InputTextBox getName() {
        return this.name;
    }

    /**
     * {@inheritDoc}
     */
    public TableGTP getResult() {
        return this.result;
    }

    /**
     * {@inheritDoc}
     */
    public Button getSearch() {
        return this.search;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void receive(final List<Person> beans) {
        final SortedHeader nameH = new SortedHeader(IMsgs.person.name(), PersonId.name);
        final SortedHeader birthH = new SortedHeader(IMsgs.person.birth(), PersonId.birth);
        final SortedHeader childH = new SortedHeader(IMsgs.person.childrens(), PersonId.childrens);
        final SortedHeader happyH = new SortedHeader(IMsgs.person.happy(), PersonId.happy);
        final SortedHeader paysH = new SortedHeader(IMsgs.person.pays(), PersonId.pays);

        this.result.setHeaders(this.buildHeader(nameH), this.buildHeader(birthH),
                this.buildHeader(childH), this.buildHeader(happyH), this.buildHeader(paysH));
        int i = 0;
        for (final Person bean : beans) {
            final Widget name = new TextValue(bean.getName());
            final Widget birth = new DateValue(bean.getBirth());
            final Widget childs = new LongTd(bean.getChildrens());
            // warn, happy can be null
            final Widget happy = null == bean.getHappy() ? new TextValue(IMsgs.global.empty())
                    : new BooleanValue(bean.getHappy());
            final Widget pays = new CurrencyTd(bean.getPays());
            // attaching elements in the table
            this.result.addLine(name, birth, childs, happy, pays);
            // we change line color
            this.result.addStyleOnCurrentLine(i++ % 2 == 0);
        }
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public PersonCriteria send(final PersonCriteria bean) {
        bean.setName(this.getName().getValue());
        // Sorted Management on server side
        bean.selectSorted(this.sorted, PersonId.name);
        return bean;
    }
}
