package gwtop.exemple.client.person.persist;

import gwtop.exemple.client.base.manager.IMsgs;
import gwtop.exemple.shared.bo.person.Person;
import gwtop.exemple.shared.id.person.PersonId;
import gwtop.fwk.mvpe.event.handler.BasicClickHandler;
import gwtop.fwk.mvpe.presenter.APresenterPersist;
import gwtop.fwk.ui.input.InputBooleanListBox;
import gwtop.fwk.ui.input.InputDateBox;
import gwtop.fwk.ui.input.InputFloatBox;
import gwtop.fwk.ui.input.InputIntegerBox;
import gwtop.fwk.ui.input.InputTextBox;

import com.google.gwt.event.dom.client.ClickHandler;
import com.google.gwt.user.client.Command;
import com.google.gwt.user.client.ui.Button;

/**
 * The Class PersonPersistPresenter.
 */
public class PersonPersistPresenter extends APresenterPersist<Person> implements
        IPersonPersistPresenter {

    /** The birth. */
    private final InputDateBox birth;

    /** The childrens. */
    private final InputIntegerBox childrens;

    /** The happy. */
    private final InputBooleanListBox happy;

    /** The name. */
    private final InputTextBox name;

    /** The ok. */
    private final Button ok;

    /** The pays. */
    private final InputFloatBox pays;

    /**
     * Instantiates a new person persist presenter.
     */
    public PersonPersistPresenter() {
        super();
        this.birth = new InputDateBox(PersonId.birth, IMsgs.person.birth(), true);
        this.childrens = new InputIntegerBox(PersonId.childrens, IMsgs.person.childrens(), true);
        this.happy = new InputBooleanListBox(PersonId.happy, IMsgs.person.happy(), false);
        this.name = new InputTextBox(PersonId.name, IMsgs.person.name(), true);
        this.pays = new InputFloatBox(PersonId.pays, IMsgs.person.pays(), true);

        this.ok = new Button(IMsgs.global.okWord());

        this.attachAll();
    }

    /**
     * Attach all.
     */
    private void attachAll() {
        // Order is important
        this.attachInput(this.name);
        this.attachInput(this.birth);
        this.attachInput(this.childrens);
        this.attachInput(this.happy);
        this.attachInput(this.pays);
        // Main button to simulate the ergonomics form
        this.attachMainButton(this.ok);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void focus() {
        this.name.getWidget().setFocus(true);
    }

    /**
     * {@inheritDoc}
     */
    public InputDateBox getBirth() {
        return this.birth;
    }

    /**
     * {@inheritDoc}
     */
    public InputIntegerBox getChildrens() {
        return this.childrens;
    }

    /**
     * {@inheritDoc}
     */
    public InputBooleanListBox getHappy() {
        return this.happy;
    }

    /**
     * {@inheritDoc}
     */
    public InputTextBox getName() {
        return this.name;
    }

    /**
     * {@inheritDoc}
     */
    public InputFloatBox getPays() {
        return this.pays;
    }

    /**
     * Gets the ok.
     * @return the ok
     */
    public Button getPersist() {
        return this.ok;
    }

    /**
     * Inits the.
     * @param cmd
     *            the cmd
     */
    public void init(final Command cmd) {
        // We initialize the persist command
        final ClickHandler handler = new BasicClickHandler(cmd);
        this.ok.addClickHandler(handler);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void receive(final Person bean) {
        this.birth.setValue(bean.getBirth());
        this.childrens.setValue(bean.getChildrens());
        this.happy.setValue(bean.getHappy());
        this.name.setValue(bean.getName());
        this.pays.setValue(bean.getPays());
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public Person send(final Person bean) {
        bean.setBirth(this.birth.getValue());
        bean.setChildrens(this.childrens.getValue());
        bean.setHappy(this.happy.getValue());
        bean.setName(this.name.getValue());
        bean.setPays(this.pays.getValue());
        return bean;
    }
}
