package gwtop.exemple.client.person.persist;

import gwtop.exemple.client.base.manager.IMsgs;
import gwtop.exemple.client.person.commons.command.PersonReadCommand;
import gwtop.exemple.shared.bo.person.Person;
import gwtop.exemple.shared.bo.person.PersonFactory;
import gwtop.exemple.shared.factory.person.IPersonFactory;
import gwtop.fwk.BasicCss;

import com.google.gwt.user.client.ui.Panel;

/**
 * The Class PersonPersistScreen.
 */
public class PersonPersistScreen extends APersonPersistScreen implements IPersonPersistScreen {

    /**
     * Instantiates a new person persist screen.
     */
    public PersonPersistScreen() {
        super(new PersonPersistPresenter(), IMsgs.person.createPerson());
        // We set the default bean
        final IPersonFactory factory = new PersonFactory();
        final Person bean = factory.instance();
        this.setBean(bean);
        // We run the screen
        final Panel screen = this.createMyPanel();
        this.add(screen);
    }

    /**
     * Instantiates a new person persist screen.
     * @param beanId
     *            the bean id
     */
    public PersonPersistScreen(final Long beanId) {
        super(new PersonPersistPresenter(), IMsgs.person.updatePerson());
        this.setUpdateMode(true);
        final PersonReadCommand cmd = new PersonReadCommand(this);
        // We set the bean and call create panel in onSuccess
        cmd.execute(beanId.toString());
    }

    /**
     * Creates the my panel.
     * @return the panel
     */
    private Panel createMyPanel() {
        final Panel screenPanel = super.createPanel();
        // We just add the ok button
        final IPersonPersistPresenter presenter = this.getPresenter();
        screenPanel.add(presenter.getPersist());
        // And add little css to render when we want
        presenter.getPersist().addStyleName(BasicCss.FLOAT_LEFT);
        return screenPanel;
    }

    /**
     * Creates the panel.
     * @return the panel
     */
    @Override
    public Panel createPanel() {
        return this.createMyPanel();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void selectUpdateMode() {
        super.selectUpdateMode();
        this.getH2().setTextTitle(IMsgs.person.updatePerson());
    }

}
